deserialize_optional_decimal_from_str

Function deserialize_optional_decimal_from_str 

pub fn deserialize_optional_decimal_from_str<'de, D>(
    deserializer: D,
) -> Result<Option<Decimal>, D::Error>
where D: Deserializer<'de>,
Deserializes an optional exact decimal, treating empty strings as absent.

Errors

Returns an error for an unsupported JSON shape or a value that cannot be represented exactly.